@@ -153,7 +153,7 @@ clibs_[eventlib.name]=eventlib
 netlib=clib()
 netlib.name='net'
 netlib.hdr=['sys/socket.h','netdb.h']
-netlib.files=[('./',['address','net','netdevice','socket','tcp','udp'])]
+netlib.files=[('./',['address','dns','net','netdevice','socket','tcp','udp'])]
 netlib.dependencies=['vmp','event']
 clibs_[netlib.name]=netlib
 
@@ -180,8 +180,8 @@ clibs_[moduleslib.name]=moduleslib
 
 jsonlib=clib()
 jsonlib.name='json'
-jsonlib.dependencies=['vmp']
-jsonlib.files=[('./',['json'])]
+jsonlib.dependencies=['vmp','net','packet']
+jsonlib.files=[('./',['json','jdata','jtable','jlist'])]
 jsonlib.libs=[('json-c','0.15')]
 jsonlib.loptions=['`pkg-config json-c --cflags --libs`']
 clibs_[jsonlib.name]=jsonlib
