@@ -145,10 +145,9 @@ pylibs_[plugin.name]=plugin
 
 json=pylib()
 json.name='vmp_json'
-json.dependencies=['vmp']
 json.cbuild()
-json.setup.files=[('./',['json_'])]
-json.setup.dependencies=['vmp','pylib','json']
+json.setup.files=[('./',['json_','jdata_','jlist_','jtable_'])]
+json.setup.dependencies=['vmp','pylib','json','net','packet']
 pylibs_[json.name]=json
 
 
