@@ -34,6 +34,7 @@ from vmp_ import CHARMIN   as CHARMIN
 from vmp_ import CHARMAX   as CHARMAX
 from vmp_ import UCHARMIN  as UCHARMIN
 from vmp_ import UCHARMAX  as UCHARMAX
+from vmp_ import RANDMAX   as RANDMAX
 
 from vmp_ import env as env
 from vmp_ import Buf as Buf
@@ -61,7 +62,9 @@ from vmp_ import system_wrap  as system_wrap
 from vmp_ import pause_wrap   as pause_wrap
 from vmp_ import getpid_wrap  as getpid_wrap
 from vmp_ import getuid_wrap  as getuid_wrap
-from vmp_ import geteuid_wrap as geteuid_wrap 
+from vmp_ import geteuid_wrap as geteuid_wrap
+from vmp_ import srand_wrap   as srand_wrap
+from vmp_ import rand_wrap    as rand_wrap  
 
 from vmp_ import fs           as fs
 
