@@ -67,6 +67,20 @@ struct stub_init:public pylib::Generic_def
     }
 };
 
+struct stub_rand_wrap:public pylib::Generic_def
+{
+    pylib::Objref *def(pylib::Args &args,pylib::KwArgs &kwargs)
+    {
+        if(args.size() == 0)
+            return pylib::Converter<vmp_uint>(vmp::rand_wrap());
+        else if(args.size() == 1)
+        {
+            vmp_uint hop=args.get<vmp_uint>(0);
+            return pylib::Converter<vmp_uint>(vmp::rand_wrap(hop));
+        }
+        return 0; 
+    }
+};
 static vmp::Table<vmp_int,pylib::PyCall *> sigcall_;
 
 void signal_handler(vmp_int sig)
@@ -122,6 +136,7 @@ void vmp_init(pylib::Module module)
     module.add_const<vmp_char>("CHARMAX",vmp::CHARMAX);
     module.add_const<vmp_uchar>("UCHARMIN",vmp::UCHARMIN);
     module.add_const<vmp_uchar>("UCHARMAX",vmp::UCHARMAX);
+    module.add_const<vmp_uint>("RANDMAX",vmp::RANDMAX);
 
     //vmp/error.h
     module.def_with_stub("except_s",stub_except_s());
@@ -150,6 +165,8 @@ void vmp_init(pylib::Module module)
     module.def_("getpid_wrap",vmp::getpid_wrap);
     module.def_("getuid_wrap",vmp::getuid_wrap);
     module.def_("geteuid_wrap",vmp::geteuid_wrap);
+    module.def_("srand_wrap",vmp::srand_wrap);
+    module.def_with_stub("rand_wrap",stub_rand_wrap());
    
     //vmp/signal.h
     module.def_("signum",vmp::signum);
