@@ -30,7 +30,7 @@
 /*!
     Const c++ in vmp/basetypes.h":<BR>
     INTMIN,INTMAX,INT16MIN,INT16MAX,UINTMIN,UINTMAX,UINT16MIN,UINT16MAX,CHARMIN,CHARMAX,
-    UCHAR_MIN,UCHAR_MAX
+    UCHAR_MIN,UCHAR_MAX,RANDMAX
 */
 /*!
     Function c++ in vmp/error.h:<BR> except_s()
@@ -40,7 +40,7 @@
     output(),output_raw(),output_file(),output_file_lines(),input(),input_file(),input_file_s(),exit_ok(),exit_failure()
 */
 /*!
-    Function c++ in vmp/lib.h:<BR>system_wrap(),getpid_wrap(),getuid_wrap(),geteuid_wrap(),pause_wrap
+    Function c++ in vmp/lib.h:<BR>system_wrap(),getpid_wrap(),getuid_wrap(),geteuid_wrap(),pause_wrap(),srand_wrap(),rand_wrap()
 */
 /*!
     Function c++ in vmp/signal.h:<BR>signum(),sigstr(),sigcmp(),signal_wrap()
