@@ -16,10 +16,13 @@
 #Author: Marco Guastella alias Vasta
 #Web page:<www.ragnu.it>
 #Email: <vasta@ragnu.it>
-#Date last Update : 23/09/2021
+#Date last Update : 10/04/2022
 
 from vmp_json_  import Json    as Json
 from vmp_json_  import JsonObj as JsonObj
+from vmp_json_  import JData   as JData
+from vmp_json_  import JList   as JList
+from vmp_json_  import JTable   as JTable
 
 
 
