@@ -60,7 +60,7 @@ struct stub_JsonObj_get_object_value:public pylib::Member_def<json::JsonObj>
     }
 };
 
-void ea_json(pylib::Module module)
+void json_init(pylib::Module module)
 {
     pylib::Class<json::Json> json=module.class_<json::Json>("Json");
     json.def_("root",&json::Json::root);
@@ -132,6 +132,9 @@ VAMPIRIA_PYLIB_INIT(vmp_json_);
 
 void vampiria_pylib_init_module(pylib::Module init_module)
 {
-    ea_json(init_module);
+    json_init(init_module);
+    json_jdata(init_module);
+    json_jlist(init_module);
+    json_jtable(init_module);
 }
 
