@@ -21,6 +21,8 @@
 
 #include "pylib.h"
 #include "vmp.h"
+#include "net.h"
+#include "packet.h"
 #include "json.h"
 
 #ifndef VAMPIRIA_PY_JSON_H
@@ -29,7 +31,7 @@
 
 //!Python wrapper of the c++ namespace vampiria::json in vmp_json.(see c++ doc)
 /*!
-    Json class in json/json.h:<BR>Constructor Json()<BR>
+    Json class in json.h:<BR>Constructor Json()<BR>
     Json member function list:<BR>root(),json_new(),json_new_obj(),json_duplicate(),parse_from_str(),
                                   parse_from_file(),json_str(),json_str_format(),json_to_file()
 */
@@ -51,7 +53,33 @@
     JsonObj member function get():<BR> function wrapper of get_str(),get_bool(),get_number() in a single function<BR>
     JsonObj member function get_object_value():<BR> function wrapper of get_object_str(),get_object_bool(),get_object_number() in a single function
 */
-void ea_json(pylib::Module module);
+void json_init(pylib::Module module);
+
+//!Python wrapper of the c++ namespace vampiria::json in vmp_json.(see c++ doc)
+/*!
+    JData class in json/jdata.h:<BR>Constructor JData()<BR>
+    JData member function list:<BR>reset(),new_data(),set(),root(),jtype(),jkey(),set_text(),get_text(),set_integer(),
+                                  get_integer(),set_integer_range(),get_integer_range(),set_real(),get_real(),
+                                  set_real_range(),get_real_range(),new_list(),set_list(),get_list(),new_table(),
+                                  set_table(),get_table(),set_args(),get_args(),set_vars(),get_vars(),set_custom(),
+                                  get_custom(),set_buf(),get_buf(),set_netaddress(),get_netaddress(),set_macaddress(),
+                                  get_macaddress(),set_packet(),get_packet()
+*/
+void json_jdata(pylib::Module module);
+
+//!Python wrapper of the c++ namespace vampiria::json in vmp_json.(see c++ doc)
+/*!
+    JList class in json/jlist.h:<BR>Constructor JList()<BR>
+    JList member function list:<BR>jdata_type(),reset(),push(),replace(),get(),size()
+*/
+void json_jlist(pylib::Module module);
+
+//!Python wrapper of the c++ namespace vampiria::json in vmp_json.(see c++ doc)
+/*!
+    JTable class in json/jtable.h:<BR>Constructor JTable()<BR>
+    JTable member function list:<BR>jdata_type(),reset(),keys(),insert(),cancel(),search()
+*/
+void json_jtable(pylib::Module module);
 
 #endif
 
