@@ -32,6 +32,14 @@ void net_init(pylib::Module module)
     module.def_("is_macaddress_raw",net::is_macaddress_raw);
     module.def_("macaddress_to_buf",net::macaddress_to_buf);
     module.def_("macaddress_from_buf",net::macaddress_from_buf);
+    
+    //net/socket.h
+    module.def_("socket_timeout",net::socket_timeout);
+    
+    //net/dns.h
+    module.def_("tcp_resolve4",net::tcp_resolve4);
+    module.def_("tcp_resolve6",net::tcp_resolve6);
+    module.def_("tcp_resolveMX",net::tcp_resolveMX);
 }
 
 VAMPIRIA_PYLIB_INIT(vmp_net_);
