@@ -16,10 +16,12 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 13/09/2021
+   Date last update: 06/04/2022
  */
 
 #include "vmp.h"
+#include "net.h"
+#include "packet.h"
 #include <json-c/json.h>
 
 #ifndef VAMPIRIA_JSON_H
@@ -269,7 +271,7 @@ class JsonObj
         */
         vmp_size get_array_size();
 
-        //! Insert the object corresponding to the index of a vector object into obj
+        //! Gets the object corresponding to the index of a vector object into obj
         /*!
             @param i index object
             @param obj output object
@@ -539,3 +541,7 @@ class JsonObj
 
 #endif
 
+#include "json/jdata.h"
+#include "json/jlist.h"
+#include "json/jtable.h"
+
