@@ -92,7 +92,7 @@ class GuiMask(gui.Frame):
     self.tagvars[entry.var]=entry
      
   def enable_button(self,wait):
-    if wait is not 0:
+    if wait != 0:
       vmp.time.vsleep(wait)
     self.cbutton.enable()    
     self.sbutton.enable()
@@ -145,7 +145,7 @@ class GuiMask(gui.Frame):
 
   def exit(self):
     self.tagvars={}
-    if self.parser is not None:
+    if self.parser != None:
       self.parser.destroy()
       self.parser=None
     self.root=None
@@ -180,7 +180,7 @@ class StaticMask(gui.Frame):
     self.refresh_button()
 
   def refresh_button(self):
-    if self.fpath is None:
+    if self.fpath == None:
       self.bsave.disable()
       self.bsaveas.disable()
       self.bdelete.disable()
@@ -197,7 +197,7 @@ class StaticMask(gui.Frame):
 
   def eopen(self):
     f=gui.popup.ask_openfilename(self,cfg.static_run_ask_,cfg.path_static_,filetypes=[("XML","*.xml")])
-    if f is not None:
+    if f != None:
       try:
         self.fpath=f
         split=vmp.unicode.str_split(self.fpath,"/")
@@ -221,7 +221,7 @@ class StaticMask(gui.Frame):
         gui.popup.showerror(title=cfg.frame_delete_error_title_(self.fname),error=str(e),parent=self)       
 
   def save(self):
-    if self.fpath is not None:
+    if self.fpath != None:
       fstr=self.editor.get_value()
       try:
         vmp.output_file(self.fpath,True,fstr)
@@ -232,7 +232,7 @@ class StaticMask(gui.Frame):
   
   def saveas(self):
     result=gui.popup.ask_saveasfilename(self,cfg.static_save_ask_,cfg.path_static_,filetypes=[("XML","*.xml")])
-    if result is not None:
+    if result != None:
       self.fpath=result
       split=vmp.unicode.str_split(self.fpath,"/")
       self.fname=split[len(split)-1]
@@ -286,7 +286,7 @@ class CustomMask(gui.Frame):
     self.refresh_button()
 
   def refresh_button(self):
-    if self.fpath is None:
+    if self.fpath == None:
       self.flabel.set_text("{0}empty".format(cfg.custom_titlepath_))
       self.bsave.disable()
       self.bsaveas.disable()
@@ -301,7 +301,7 @@ class CustomMask(gui.Frame):
 
   def eopen(self):
     f=gui.popup.ask_openfilename(self,cfg.custom_run_ask_,cfg.path_custom_,filetypes=[("XML","*.xml")])
-    if f is not None:
+    if f != None:
       try:
         self.fpath=f
         split=vmp.unicode.str_split(self.fpath,"/")
@@ -313,7 +313,7 @@ class CustomMask(gui.Frame):
         pass
 
   def save(self):
-    if self.fpath is not None:
+    if self.fpath != None:
       fstr=self.editor.get_value()
       try:
         vmp.output_file(self.fpath,True,fstr)
@@ -324,7 +324,7 @@ class CustomMask(gui.Frame):
 
   def saveas(self):
     result=gui.popup.ask_saveasfilename(self,cfg.custom_save_ask_,cfg.path_custom_,filetypes=[("XML","*.xml")])
-    if result is not None:
+    if result != None:
       self.fpath=result
       split=vmp.unicode.str_split(self.fpath,"/")
       self.fname=split[len(split)-1]
@@ -424,7 +424,7 @@ class TopFrame(gui.Frame):
   def open_dirproject(self):
     try:
       self.group=self.ggui.get_value()
-      if self.group is None:
+      if self.group == None:
         gui.popup.showerror(title=cfg.main_ggui_error_title_,error=cfg.main_ggui_error_,parent=self)
       else:
         ldata=vmp.fs.listendir("{0}{1}/".format(cfg.path_project_,self.group))
@@ -441,7 +441,7 @@ class TopFrame(gui.Frame):
 
   def run_project(self):
     name=self.gui.get_value()
-    if  name is not None:
+    if  name != None:
       filepath="{0}{1}/{2}.xml".format(cfg.path_project_,self.group,name)
       wmask=GuiMask(name)    
       try:
